@@ -271,13 +271,17 @@ class ItemAdapter(MutableMapping):
 
     @classmethod
     def is_item(cls, item: Any) -> bool:
-        return any(adapter_class.is_item(item) for adapter_class in cls.ADAPTER_CLASSES)
+        for adapter_class in cls.ADAPTER_CLASSES:
+            if adapter_class.is_item(item):
+                return True
+        return False
 
     @classmethod
     def is_item_class(cls, item_class: type) -> bool:
-        return any(
-            adapter_class.is_item_class(item_class) for adapter_class in cls.ADAPTER_CLASSES
-        )
+        for adapter_class in cls.ADAPTER_CLASSES:
+            if adapter_class.is_item_class(item_class):
+                return True
+        return False
 
     @classmethod
     def get_field_meta_from_class(cls, item_class: type, field_name: str) -> MappingProxyType:
@@ -292,7 +296,7 @@ class ItemAdapter(MutableMapping):
 
     def __repr__(self) -> str:
         values = ", ".join([f"{key}={value!r}" for key, value in self.items()])
-        return f"<ItemAdapter for {self.item.__class__.__name__}({values})>"
+        return f"<{self.__class__.__name__} for {self.item.__class__.__name__}({values})>"
 
     def __getitem__(self, field_name: str) -> Any:
         return self.adapter.__getitem__(field_name)
